@@ -3,7 +3,7 @@ from django.contrib.auth import models as auth_models
 from django.utils import timezone
 import datetime
 from django.utils.translation import ugettext_lazy as _
-
+from corgy_mdm import models as mdm_models
 # Create your models here.
 
 class ActivityModel(models.Model):
@@ -22,10 +22,13 @@ class WorksheetModel(models.Model):
         verbose_name = _('worksheet')
 
     owner = models.ForeignKey(
-        to=auth_models.User,
+        to=mdm_models.PersonModel,
         on_delete=models.CASCADE
     )
 
+    def __str__(self):
+        return str(self.owner)
+
     def daily_entries(self, timestamp: datetime.datetime):
         return self.entries.filter(
             worksheet = self,
@@ -34,7 +37,7 @@ class WorksheetModel(models.Model):
             timestamp__day = timestamp.day
         )
 
-    def daily_summary(self, timestamp: datetime.datetime):
+    def daily_summary(self, timestamp: timezone.datetime):
         return self.entries.aggregate(daily_work = models.Sum('duration'))['daily_work'] #type:
 
 class WorksheetEntryModel(models.Model):
